#
# spec file for package libnfc
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libnfc
%define lname	libnfc6
Version:        1.8.0
Release:        1.16
Summary:        Library for Near Field Communication
License:        LGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://libnfc.org/

#Git-Clone:	https://github.com/nfc-tools/libnfc
Source:         https://github.com/nfc-tools/libnfc/releases/download/%name-%version/%name-%version.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkg-config
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(libpcsclite)
BuildRequires:  pkgconfig(libusb)

%description
libnfc is a low-level SDK for various RFID and NFC applications.

It supports various NFC hardware devices: dongles, flat and OEM
devices. The library currently supports modulations for ISO/IEC 14443
(A and B), FeliCa, Jewel tags and Data Exchange Protocol (P2P) as
target and as initiator.

%package -n %lname
Summary:        Library for Near Field Communication
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
libnfc is a low-level SDK for various RFID and NFC applications.

It supports various NFC hardware devices: dongles, flat and OEM
devices. The library currently supports modulations for ISO/IEC 14443
(A and B), FeliCa, Jewel tags and Data Exchange Protocol (P2P) as
target and as initiator.

%package devel
Summary:        Development files for the Near Field Communications library
License:        LGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libnfc is a low-level SDK for various RFID and NFC applications.

It supports various NFC hardware devices: dongles, flat and OEM
devices. The library currently supports modulations for ISO/IEC 14443
(A and B), FeliCa, Jewel tags and Data Exchange Protocol (P2P) as
target and as initiator.

This package contains the libnfc development files.

%package tools
Summary:        Tools for Near Field Communication
License:        LGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Hardware/Other

%description tools
libnfc is a low-level SDK for various RFID and NFC applications.

It supports various NFC hardware devices: dongles, flat and OEM
devices. The library currently supports modulations for ISO/IEC 14443
(A and B), FeliCa, Jewel tags and Data Exchange Protocol (P2P) as
target and as initiator.

This package contains the NFC utilities.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
rm -fv "%buildroot/%_libdir"/*.la
mkdir -p "%buildroot/%_sysconfdir/nfc"

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libnfc.so.6*

%files devel
%_includedir/nfc
%_libdir/libnfc.so
%_libdir/pkgconfig/libnfc.pc

%files tools
%_bindir/nfc-*
%_bindir/pn53x-*
%_mandir/man*/*.1*
%dir %_sysconfdir/nfc
%doc libnfc.conf.sample

%changelog
* Thu May 21 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.0
  * New driver for pn71xx NXP's NFC Controllers through Linux
    Libnfc-nci (untested).
  * New driver for contactless PC/SC readers (only as initiator).
  * nfc_device_get_supported_baud_rate() now takes also "mode" as
    argument.
  * New nfc_device_get_supported_baud_rate_target_mode()
  * New NFC modulation type NMT_BARCODE and nfc_barcode_info
    struct to support Thinfilm NFC Barcode protocol.
  * New NFC modulation type NMT_ISO14443BICLASS and
    NMT_ISO14443BICLASS struct to support HID iClass (Picopass).
  * pn53x_transceive() is now part of public API
* Mon Jul  3 2017 jengelh@inai.de
- Ship sample config file
* Tue Mar 17 2015 jengelh@inai.de
- Restore build on SLE11.
* Mon Aug 11 2014 jengelh@inai.de
- Update to new upstream release 1.7.1
  * API behavioral changes:
  * nfc_initiator_select_passive_target() provides defaults if
  pbtInitData=NULL
  * nfc_initiator_target_is_present() allows NULL pointer to tag
* Tue Dec 24 2013 jengelh@inai.de
- Update to final release 1.7.0
  * pn53x: only create a current target when at least one have been
  found
  * pn532_uart: fix 'operation abort' feature with this driver
  * pn532_uart: let more time to PN532 to wake-up, this fix some
  specific cases where PN532 shown one of two runs
  * usb: fix USB enumeration issue
  * Fix pn53x_initiator_transceive_bytes_timed() measures for TypeB
* Fri May 31 2013 jengelh@inai.de
- Update to new upstream release 1.7.0~rc7
  * New PN532 over SPI driver
  * libnfc can now use a configuration file for special setups, or
  feature activation. (/etc/nfc/libnfc.conf)
- Remove libnfc-01-automake.diff, merged upstream
* Thu Mar 14 2013 cfarrell@suse.com
- license update: LGPL-3.0+ and GPL-2.0+
  examples are under GPL-2.0Ã+
* Wed Mar  6 2013 coolo@suse.com
- update license to new format
* Fri Jun 15 2012 jengelh@inai.de
- Initial package for build.opensuse.org
